@@ -7,7 +7,7 @@ from copy import deepcopy
 import time
 
 #@nb.jit(nopython=True,cache=True,nogil=True)
-def add_bifurcation(tree,parent_edge,candidate_point,results,optimum):
+def add_bifurcation(tree,parent_edge,candidate_point,results,optimum,isforest=False):
     ########### UNPACK LOCAL OPTIMIZATION DATA ##############
     start = time.time()
     R0  = results[0]
@@ -25,17 +25,21 @@ def add_bifurcation(tree,parent_edge,candidate_point,results,optimum):
     alt_scale          = np.array(results[13])
     R_terminal = results[14]
     R_sister   = results[15]
-    #sub_division_map    = deepcopy(tree.sub_division_map)
-    #sub_division_index  = deepcopy(tree.sub_division_index)
-    sub_division_map    = tree.sub_division_map
-    sub_division_index  = tree.sub_division_index
+    if isforest:
+        sub_division_map    = deepcopy(tree.sub_division_map)
+        sub_division_index  = deepcopy(tree.sub_division_index)
+    else:
+        sub_division_map    = tree.sub_division_map
+        sub_division_index  = tree.sub_division_index
     Qterm               = tree.parameters['Qterm']
     tree.time['add_1'].append(time.time()-start)
     ###########################################################
     ############### Copy Data and Make New ####################
     start = time.time()
-    #data = deepcopy(tree.data[tree.data[:,-1]>-1])
-    data = tree.data
+    if isforest:
+        data = deepcopy(tree.data)
+    else:
+        data = tree.data
     #if sum(tree.data[tree.data[:,-1]==-1]) == 0:
     #    nosegments = True
     #else:
